# 1.1.0

- Revamped to work off an expected list of articles/categories fetched from API
- Fixed category page icon size (#106)
- Removed devel param --skip-relateds
- Added --api-delay option
- Using the previously unused --delay option
- Better exit upon errors (#105)

# 1.0.2

- Allow creation of usable ZIM from single category using --category

# 1.0.1

- Using pylibzim 1.0.0 and zimscraperlib 1.4.0
- Fixed crash on incorrect link during --exclude rewrite (#101)
- Removed a link to author on sidebar (#102)

# 1.0.0

- initial version
